package Limper::Plugin;
$Limper::Plugin::VERSION = '0.014';
use 5.10.0;
use strict;
use warnings;

1;

__END__

=head1 NAME

Limper::Plugin - placeholder for the Limper::Plugin namespace

=head1 VERSION

version 0.014

=head1 SYNOPSIS

Do not use this module directly. It currently does absolutely nothing, and likely never will.

=head1 DESCRIPTION

See L<Limper::Extending> for how to write L<Limper> plugins.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Ashley Willis E<lt>ashley+perl@gitable.orgE<gt>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.12.4 or,
at your option, any later version of Perl 5 you may have available.
